import { InjectionToken, Provider } from '@angular/core';
import { RxCustomStrategyCredentials, RxDefaultStrategyNames, RxStrategyNames } from './model';
export interface RxRenderStrategiesConfig<T extends string> {
    primaryStrategy?: RxStrategyNames<T>;
    customStrategies?: RxCustomStrategyCredentials<T>;
    patchZone?: boolean;
    /**
     *  @deprecated This flag will be dropped soon, as it is no longer required when using signal based view & content queries
     */
    parent?: boolean;
}
export declare const RX_RENDER_STRATEGIES_CONFIG: InjectionToken<RxRenderStrategiesConfig<string>>;
export declare const RX_RENDER_STRATEGIES_DEFAULTS: Required<RxRenderStrategiesConfig<RxDefaultStrategyNames>>;
export declare function mergeDefaultConfig<T extends string>(cfg?: RxRenderStrategiesConfig<T>): Required<RxRenderStrategiesConfig<T | RxDefaultStrategyNames>>;
/**
 * @description
 * Can be used to set the default render strategy or create custom render strategies.
 *
 * With this function you can customize the behavior of:
 * - `rxLet` directive
 * - `rxFor` directive
 * - `rxIf` directive
 * - `rxVirtualFor` directive
 * - `rxVirtualView` directive
 * - `RxStrategyProvider` service.
 *
 * @example
 * import { provideRxRenderStrategies } from '@rx-angular/cdk/render-strategies';
 *
 * const appConfig: ApplicationConfig = {
 *   providers: [
 *     provideRxRenderStrategies({
 *       primaryStrategy: 'sync',
 *       customStrategies: {
 *         sync: {
 *           name: 'sync',
 *           work: (cdRef) => { cdRef.detectChanges(); },
 *           behavior: ({ work }) => (o$) => o$.pipe(tap(() => work()))
 *          },
 *         asap: {
 *           name: 'asap',
 *           work: (cdRef) => { cdRef.detectChanges(); },
 *           behavior: ({ work }) => (o$) => o$.pipe(delay(0, asapScheduler), tap(() => work()))
 *        },
 *     }),
 *   ],
 * };
 *
 * @param config - The configuration object.
 * @returns A provider that can be used to set the default render strategy or create custom render strategies.
 */
export declare function provideRxRenderStrategies(config: RxRenderStrategiesConfig<string>): Provider;
